dot-matchesAndRegexes: Create a list of matched files in the system and unmatched...

.matchesAndRegexesR Documentation

Create a list of matched files in the system and unmatched regular expessions

Description

Create a list of matched files in the system and unmatched regular expessions

Usage

.matchesAndRegexes(rgx)

Arguments

rgx

string to expand in the system

Value

a list of all the elements after possible expansion


pepr documentation built on March 1, 2026, 1:07 a.m.