saveJWT: Save or update JWT

View source: R/utils.R

saveJWTR Documentation

Save or update JWT

Description

Save or update local authentication token to fetch private PEPs

Usage

saveJWT(jwt)

Arguments

jwt

a string for the new jwt to save

Value

a boolean for whether the authentication token was saved


pepr documentation built on March 1, 2026, 1:07 a.m.