saveProject: Save a modified PEP Project to a local directory

View source: R/utils.R

saveProjectR Documentation

Save a modified PEP Project to a local directory

Description

This is a helper that saves a PEP Project to a local output directory

Usage

saveProject(project = NULL, outputDir = getwd(), overwrite = FALSE)

Arguments

project

a PEP Project

outputDir

a string for the output directory, defaults to current working directory

overwrite

a boolean for whether to overwrite an existing project at the output directory

Value

a boolean, TRUE if the save was successful and FALSE if otherwise


pepr documentation built on March 1, 2026, 1:07 a.m.