.mergeAttrs: Merge samples defined in sample table with ones in subsample table(s)
Description
Merge samples defined in sample table with ones in subsample table(s)
Usage
.mergeAttrs(.Object, subsampleAannotationPaths, subsamplesTables = NULL)
Value
an object of "Project"
Arguments
- .Object
an object of "Project"
- subsampleAannotationPaths
a vector of strings specifying the paths to sample