.modifySamplesFetched: Perform all the sample attribute modifications for fetched PEPs
Description
Perform all the sample attribute modifications for fetched PEPs
Usage
.modifySamplesFetched(object, subsamples)
Value
modified Project object
Arguments
- object
an object of "Project"