| saveJWT | R Documentation |
Save or update local authentication token to fetch private PEPs
saveJWT(jwt)
jwt |
a string for the new jwt to save |
a boolean for whether the authentication token was saved
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.