Learn R Programming

pepr (version 0.6.0)

saveJWT: Save or update JWT

Description

Save or update local authentication token to fetch private PEPs

Usage

saveJWT(jwt)

Value

a boolean for whether the authentication token was saved

Arguments

jwt

a string for the new jwt to save