| saveProject | R Documentation |
This is a helper that saves a PEP Project to a local output directory
saveProject(project = NULL, outputDir = getwd(), overwrite = FALSE)
project |
a PEP Project |
outputDir |
a string for the output directory, defaults to current working directory |
overwrite |
a boolean for whether to overwrite an existing project at the output directory |
a boolean, TRUE if the save was successful and FALSE if otherwise
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.