Learn R Programming

pepr (version 0.6.0)

saveProject: Save a modified PEP Project to a local directory

Description

This is a helper that saves a PEP Project to a local output directory

Usage

saveProject(project = NULL, outputDir = getwd(), overwrite = FALSE)

Value

a boolean, TRUE if the save was successful and FALSE if otherwise

Arguments

project

a PEP Project

outputDir

a string for the output directory, defaults to current working directory

overwrite

a boolean for whether to overwrite an existing project at the output directory