This is a helper that saves a PEP Project to a local output directory
saveProject(project = NULL, outputDir = getwd(), overwrite = FALSE)a boolean, TRUE if the save was successful and FALSE if otherwise
a PEP Project
a string for the output directory, defaults to current working directory
a boolean for whether to overwrite an existing project at the output directory